@@ -58,8 +58,8 @@ API Reference
 #include "sqlite3.h"
 #endif
 
-#if SQLITE_VERSION_NUMBER < 3008005
-#error Your SQLite version is too old.  It must be at least 3.8.5
+#if SQLITE_VERSION_NUMBER < 3008009
+#error Your SQLite version is too old.  It must be at least 3.8.9
 #endif
 
 /* system headers */
@@ -278,8 +278,9 @@ sqliteshutdown(void)
   Many operations don't make sense from a Python program.  The
   following configuration operations are supported: SQLITE_CONFIG_LOG,
   SQLITE_CONFIG_SINGLETHREAD, SQLITE_CONFIG_MULTITHREAD,
-  SQLITE_CONFIG_SERIALIZED, SQLITE_CONFIG_URI, SQLITE_CONFIG_MEMSTATUS
-  and SQLITE_CONFIG_COVERING_INDEX_SCAN.
+  SQLITE_CONFIG_SERIALIZED, SQLITE_CONFIG_URI, SQLITE_CONFIG_MEMSTATUS,
+  SQLITE_CONFIG_COVERING_INDEX_SCAN, SQLITE_CONFIG_PCACHE_HDRSZ, and
+  SQLITE_CONFIG_PMASZ.
 
   See :ref:`tips <diagnostics_tips>` for an example of how to receive
   log messages (SQLITE_CONFIG_LOG)
@@ -349,8 +350,23 @@ config(APSW_ARGUNUSED PyObject *self, PyObject *args)
       res=sqlite3_config( (int)opt );
       break;
 
+    case SQLITE_CONFIG_PCACHE_HDRSZ:
+      {
+        int outval=-1;
+        if(!PyArg_ParseTuple(args, "i", &optdup))
+          return NULL;
+        assert(opt==optdup);
+        res=sqlite3_config( (int)opt, &outval );
+        if(res) {
+          SET_EXC(res, NULL);
+          return NULL;
+        }
+        return PyInt_FromLong(outval);
+      }
+
     case SQLITE_CONFIG_MEMSTATUS:
     case SQLITE_CONFIG_COVERING_INDEX_SCAN:
+    case SQLITE_CONFIG_PMASZ:
       {
         int boolval;
         if(!PyArg_ParseTuple(args, "ii", &optdup, &boolval))
@@ -516,24 +532,25 @@ releasememory(APSW_ARGUNUSED PyObject *self, PyObject *args)
 
     * :ref:`Status example <example-status>`
 
-  -* sqlite3_status
+  -* sqlite3_status64
 
 */
 static PyObject *
 status(APSW_ARGUNUSED PyObject *self, PyObject *args)
 {
-  int res, op, current=0, highwater=0, reset=0;
+  int res, op, reset=0;
+  sqlite3_int64 current=0, highwater=0;
 
   if(!PyArg_ParseTuple(args, "i|i:status(op, reset=False)", &op, &reset))
     return NULL;
 
-  res=sqlite3_status(op, &current, &highwater, reset);
+  res=sqlite3_status64(op, &current, &highwater, reset);
   SET_EXC(res, NULL);
 
   if(res!=SQLITE_OK)
     return NULL;
 
-  return Py_BuildValue("(ii)", current, highwater);
+  return Py_BuildValue("(LL)", current, highwater);
 }
 
 /** .. method:: vfsnames() -> list(string)
@@ -1366,8 +1383,8 @@ numeric value, or supply a numeric value and get the corresponding
 string. These can help improve diagnostics/logging, calling other
 modules etc. For example::
 
-      apsw.mapping_authorizer_function["SQLITE_READ"]=20
-      apsw.mapping_authorizer_function[20]="SQLITE_READ"
+      apsw.mapping_authorizer_function["SQLITE_READ"] == 20
+      apsw.mapping_authorizer_function[20] == "SQLITE_READ"
 
 
     */
@@ -1491,6 +1508,7 @@ modules etc. For example::
       ADDINT(SQLITE_IOERR_CONVPATH),
       ADDINT(SQLITE_CONSTRAINT_ROWID),
       ADDINT(SQLITE_READONLY_DBMOVED),
+      ADDINT(SQLITE_AUTH_USER),
       END,
 
       /* error codes */
@@ -1524,6 +1542,9 @@ modules etc. For example::
       ADDINT(SQLITE_TOOBIG),
       ADDINT(SQLITE_NOTICE),
       ADDINT(SQLITE_WARNING),
+      /* you can't get these from apsw code but present for completeness */
+      ADDINT(SQLITE_DONE),
+      ADDINT(SQLITE_ROW),
       END,
 
       /* open flags */
@@ -1563,6 +1584,7 @@ modules etc. For example::
       ADDINT(SQLITE_LIMIT_LIKE_PATTERN_LENGTH),
       ADDINT(SQLITE_LIMIT_VARIABLE_NUMBER),
       ADDINT(SQLITE_LIMIT_TRIGGER_DEPTH),
+      ADDINT(SQLITE_LIMIT_WORKER_THREADS),
       /* We don't include the MAX limits - see https://github.com/rogerbinns/apsw/issues/17 */
       END,
 
@@ -1589,6 +1611,8 @@ modules etc. For example::
       ADDINT(SQLITE_CONFIG_SQLLOG),
       ADDINT(SQLITE_CONFIG_MMAP_SIZE),
       ADDINT(SQLITE_CONFIG_WIN32_HEAPSIZE),
+      ADDINT(SQLITE_CONFIG_PCACHE_HDRSZ),
+      ADDINT(SQLITE_CONFIG_PMASZ),
       END,
 
       DICT("mapping_db_config"),
@@ -1666,13 +1690,11 @@ modules etc. For example::
       ADDINT(SQLITE_CHECKPOINT_PASSIVE),
       ADDINT(SQLITE_CHECKPOINT_FULL),
       ADDINT(SQLITE_CHECKPOINT_RESTART),
+      ADDINT(SQLITE_CHECKPOINT_TRUNCATE),
       END,
 
       DICT("mapping_file_control"),
       ADDINT(SQLITE_FCNTL_LOCKSTATE),
-      ADDINT(SQLITE_GET_LOCKPROXYFILE),
-      ADDINT(SQLITE_SET_LOCKPROXYFILE),
-      ADDINT(SQLITE_LAST_ERRNO),
       ADDINT(SQLITE_FCNTL_SIZE_HINT),
       ADDINT(SQLITE_FCNTL_CHUNK_SIZE),
       ADDINT(SQLITE_FCNTL_FILE_POINTER),
@@ -1691,6 +1713,29 @@ modules etc. For example::
       ADDINT(SQLITE_FCNTL_HAS_MOVED),
       ADDINT(SQLITE_FCNTL_SYNC),
       ADDINT(SQLITE_FCNTL_WIN32_SET_HANDLE),
+      ADDINT(SQLITE_FCNTL_LAST_ERRNO),
+      ADDINT(SQLITE_FCNTL_WAL_BLOCK),
+      ADDINT(SQLITE_FCNTL_GET_LOCKPROXYFILE),
+      ADDINT(SQLITE_FCNTL_SET_LOCKPROXYFILE),
+      END,
+
+      DICT("mapping_conflict_resolution_modes"),
+      ADDINT(SQLITE_ROLLBACK),
+      ADDINT(SQLITE_IGNORE),
+      ADDINT(SQLITE_FAIL),
+      ADDINT(SQLITE_ABORT),
+      ADDINT(SQLITE_REPLACE),
+      END,
+
+      DICT("mapping_virtual_table_configuration_options"),
+      ADDINT(SQLITE_VTAB_CONSTRAINT_SUPPORT),
+      END,
+
+      DICT("mapping_xshmlock_flags"),
+      ADDINT(SQLITE_SHM_EXCLUSIVE),
+      ADDINT(SQLITE_SHM_LOCK),
+      ADDINT(SQLITE_SHM_SHARED),
+      ADDINT(SQLITE_SHM_UNLOCK),
       END
 
       };
